@@ -13,14 +13,6 @@ our $RX_PKG           = qr/^[A-Z_a-z]$RX_PKG_NOT_FIRST*$/;
 use constant SUBRE => qr/^[a-zA-Z_]\w*$/;
 sub check_subname { $_[0] =~ SUBRE }
 
-my $DEBUG;
-sub debug { return unless $DEBUG; carp "[${\(caller)[0]}]: $_[0]"; }
-
-sub enable_debug($on) {
-  $DEBUG = $on;
-}
-enable_debug($ENV{EVO_DEBUG});
-
 # usefull?
 sub find_caller_except ($skip_ns, $i, $caller) {
   while ($caller = (caller($i++))[0]) {
@@ -61,12 +53,14 @@ sub monkey_patch_silent ($pkg, %hash) {
 }
 
 # returns a package where code was declared and a name
-# TODO: determine better way constants like from Fcntl (better than XSUB)
+# ->CONST not documented, but exists in B::CV and defined in /CORE/cv.h as
+# define CvCONST(cv)		(CvFLAGS(cv) & CVf_CONST)
+# this flag is used by Evo::Class to determine that constants should be inherited
 sub code2names($r) {
   my $sv    = svref_2object($r);
   my $gv    = $sv->GV;
   my $stash = $gv->STASH;
-  ($stash->NAME, $gv->NAME, $sv->XSUB);
+  ($stash->NAME, $gv->NAME, $sv->CONST);
 }
 
 sub names2code ($pkg, $name) {
@@ -86,10 +80,10 @@ sub list_symbols($pkg) {
 #}
 
 
-sub uniq {
-  my %seen;
-  return grep { !$seen{$_}++ } @_;
-}
+#sub uniq {
+#  my %seen;
+#  return grep { !$seen{$_}++ } @_;
+#}
 
 # returns a subroutine than can pretend a code in the other package/file/line
 sub inject(%opts) {
@@ -159,7 +153,7 @@ Evo::Internal::Util
 
 =head1 VERSION
 
-version 0.0244
+version 0.0245
 
 =head1 DESCRIPTION
 
